@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-import re
+import re, types
 from PyQt5.QtWidgets import QApplication
 from qasync import QEventLoop
 import sys, asyncio, os
@@ -47,6 +47,22 @@ class Parser:
             if 'id' in e.attrsToDict.keys():
                 self.idElements[e.attrsToDict['id']] = e
 
+    def reloadEvent(self, id, name, func):
+        obj = self.idElements[id]
+        setattr(obj.qt, name, types.MethodType(func(), getattr(obj, 'qt')))
+
+    # Event Example
+    # def mainCloseEvent(self):
+    #     main = self
+    #     def _event(self, event):
+    #         result = QMessageBox.question(self, "操作询问", "是否关闭程序?", QMessageBox.Yes | QMessageBox.No)
+    #         if(result == QMessageBox.Yes):
+    #             main.events.box.close()
+    #             event.accept()
+    #         else:
+    #             event.ignore()
+    #     return _event
+
     def run(self):
         with self.loop:
             self.loop.run_forever()
